EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Feeds_AddFeedConnector',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Associates a connector with a feed.'
GO

IF OBJECT_ID('[Feeds_AddFeedConnector]') IS NOT NULL DROP PROCEDURE [Feeds_AddFeedConnector]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Feeds_AddFeedConnector]
(
	@Feed_Id INT,
	@Connector_Id INT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

    DECLARE @Next_Sequence_Number INT

    SELECT @Next_Sequence_Number = COALESCE(MAX([Sequence_Number]), 0) + 1
      FROM [FeedConnectors]
     WHERE [Feed_Id] = @Feed_Id

	DELETE [FeedConnectors] 
     WHERE [Feed_Id] = @Feed_Id 
       AND [Connector_Id] = @Connector_Id

    INSERT INTO [FeedConnectors] ([Feed_Id], [Sequence_Number], [Connector_Id])
    VALUES (@Feed_Id, @Next_Sequence_Number, @Connector_Id)


    COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Feeds_AddFeedConnector] TO [ProGetUser_Role]
GO
