EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'VsixPackages_CreateOrUpdatePackage',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates a new package or updates an existing one.'
GO

IF OBJECT_ID('[VsixPackages_CreateOrUpdatePackage]') IS NOT NULL DROP PROCEDURE [VsixPackages_CreateOrUpdatePackage]
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO

CREATE PROCEDURE [VsixPackages_CreateOrUpdatePackage]
(
	@Feed_Id INT,
	@Package_Id VARCHAR(100),
	@Major_Number INT,
	@Minor_Number INT,
	@Build_Number INT,
	@Revision_Number INT,
	@Tags_Csv NVARCHAR(100),
	@DisplayName_Text NVARCHAR(100),
	@Icon_Path VARCHAR(100),
	@PreviewImage_Path VARCHAR(100),
	@Author_Text NVARCHAR(100),
	@Description_Text NVARCHAR(1000),
	@Manifest_Bytes VARBINARY(MAX),
	@Published_Date DATETIME,
	@Cached_Indicator YNINDICATOR,
	@PackageHash_Bytes BINARY(20),
	@Package_Size BIGINT
)
AS
BEGIN

SET NOCOUNT ON
SET QUOTED_IDENTIFIER ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @Version_Text VARCHAR(200)
	SET @Version_Text = CAST(@Major_Number AS VARCHAR(50)) + '.' + CAST(@Minor_Number AS VARCHAR(50)) + '.' + CAST(@Build_Number AS VARCHAR(50)) + '.' + CAST(@Revision_Number AS VARCHAR(50))

	IF NOT EXISTS(SELECT * FROM [VsixPackages] WHERE [Feed_Id] = @Feed_Id AND [Package_Id] = @Package_Id AND [Major_Number] = @Major_Number AND [Minor_Number] = @Minor_Number AND [Build_Number] = @Build_Number AND [Revision_Number] = @Revision_Number)
	BEGIN

		INSERT INTO [VsixPackages]
		(
			[Feed_Id],
			[Package_Id],
			[Major_Number],
			[Minor_Number],
			[Build_Number],
			[Revision_Number],
			[Tags_Csv],
			[DisplayName_Text],
			[Icon_Path],
			[PreviewImage_Path],
			[Author_Text],
			[Description_Text],
			[Manifest_Bytes],
			[Download_Count],
			[Published_Date],
			[Cached_Indicator],
			[PackageHash_Bytes],
			[Package_Size]
		)
		VALUES
		(
			@Feed_Id,
			@Package_Id,
			@Major_Number,
			@Minor_Number,
			@Build_Number,
			@Revision_Number,
			@Tags_Csv,
			@DisplayName_Text,
			@Icon_Path,
			@PreviewImage_Path,
			@Author_Text,
			@Description_Text,
			@Manifest_Bytes,
			0,
			@Published_Date,
			@Cached_Indicator,
			@PackageHash_Bytes,
			@Package_Size
		)

		EXEC [Events_RaiseEvent] 'PKGADD', @Feed_Id, 'Package_Name', @Package_Id, 'Package_Version', @Version_Text

	END
	ELSE
	BEGIN

		UPDATE [VsixPackages]
		   SET [Tags_Csv] = @Tags_Csv,
		       [DisplayName_Text] = @DisplayName_Text,
			   [Icon_Path] = @Icon_Path,
			   [PreviewImage_Path] = @PreviewImage_Path,
			   [Author_Text] = @Author_Text,
			   [Description_Text] = @Description_Text,
			   [Manifest_Bytes] = @Manifest_Bytes,
			   [Published_Date] = @Published_Date,
			   [Cached_Indicator] = @Cached_Indicator,
			   [PackageHash_Bytes] = @PackageHash_Bytes,
			   [Package_Size] = @Package_Size
		 WHERE [Feed_Id] = @Feed_Id
		   AND [Package_Id] = @Package_Id
		   AND [Major_Number] = @Major_Number
		   AND [Minor_Number] = @Minor_Number
		   AND [Build_Number] = @Build_Number
		   AND [Revision_Number] = @Revision_Number

   		IF COALESCE(dbo.Session_GetUserName(), 'UNKNOWN') NOT IN ('SYSTEM', 'UNKNOWN')
			EXEC [Events_RaiseEvent] 'PKGMDF', @Feed_Id, 'Package_Name', @Package_Id, 'Package_Version', @Version_Text

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [VsixPackages_CreateOrUpdatePackage] TO [ProGetUser_Role]